@@ -217,6 +217,9 @@ class TextField(ModelField):
         if len(args) is 1:
             text = args[0]
 
+            if not text and not self.null:
+                raise Exception('Value cannot be None')
+
             if isinstance(text, basestring):
                 self.text = u'%s' % args[0]
             else:
@@ -446,13 +449,19 @@ class DatetimeField(ModelField):
         """
         """
 
-        return u'%s' % self.time.strftime(DatetimeField.DATE_FORMAT)
+        if self.time and not self.null:
+            return u'%s' % self.time.strftime(DatetimeField.DATE_FORMAT)
+        else:
+            return None
 
     def loads(self, date_string):
         """
         """
 
-        self.time = datetime.strptime(date_string, DatetimeField.DATE_FORMAT)
+        if not self.null:
+            self.time = datetime.strptime(date_string, DatetimeField.DATE_FORMAT)
+        else:
+            self.time = None
 
     def validate(self):
         """
@@ -507,13 +516,19 @@ class DateField(ModelField):
         """
         """
 
-        return u'%s' % self.date.strftime(DateField.DATE_FORMAT)
+        if self.date and not self.null:
+            return u'%s' % self.date.strftime(DateField.DATE_FORMAT)
+        else:
+            return None
 
     def loads(self, date_string):
         """
         """
 
-        self.date = datetime.strptime(date_string, DateField.DATE_FORMAT)
+        if not self.null:
+            self.date = datetime.strptime(date_string, DateField.DATE_FORMAT)
+        else:
+            self.date = None
 
     def validate(self):
         """
